Changelog
---------

v1.6.0 (2014-03-11)
~~~~~~~~~~~~~~~~~~~

* backward compatibility breaking release!
* most of things was rewritten
* from now on there will be separate branch for each major Django version and Django Wp Admin will be versioned according to Django version it supports...
* ...so this version is compatible only with Django 1.6.x
* all JavaScript libraries updated
* FontAwesome updated to version 4.0.3
* new WordPress admin look
* styles for selector widget
* styles for calendar widget
* styles for timepicker widget
* styles for delete confirmation page
* styles for history page
* collapsible fieldsets can be opened by default
* 7 additional color themes added
* added licenses for all included external files (fonts and JS)
* support for nested submenus


v0.2.0 (2013-04-02)
~~~~~~~~~~~~~~~~~~~

* styled object's editing pages


v0.1.2 (2013-03-23)
~~~~~~~~~~~~~~~~~~~

* **Django 1.3 support dropped!** (there's too much differences between Django 1.3 and 1.4)
* installation process slightly changed (there's no need to copy or symlink base.html file for specific Django version)
* added WordPress look and feel for objects lists (change_list.html)
* CHANGELOG added


v0.1.1 (2013-03-19)
~~~~~~~~~~~~~~~~~~~

* installation scripts
* README and LICENSE files added


v0.1.0 (2013-03-19)
~~~~~~~~~~~~~~~~~~~

* top and left menu
